import os
import time
import sys
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filechecker(FILENAME):
    if os.path.isfile(FILENAME):
        print(bcolors.OKGREEN + "%s file is created" % FILENAME + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "%s file is not created, please try again" % FILENAME + bcolors.ENDC)
    time.sleep(0.5)
   
   

def folderchecker(FOLDERNAME):
    if os.path.isdir(FOLDERNAME):
        print(bcolors.OKGREEN + "%s is created" % FOLDERNAME + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "%s is not created, please try again" %FOLDERNAME + bcolors.ENDC)
    time.sleep(0.5)


def sizechecker(FILENAME):
    try:
        if os.path.getsize(FILENAME) <= 0:
            print(bcolors.FAIL + "%s"  + " seems to be empty" % FILENAME + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + "The %s is not empty" % FILENAME + bcolors.ENDC) 
        time.sleep(0.5)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)


def linechecker(FILENAME):
    try:
        num_lines = sum(1 for line in open(FILENAME))
        sizechecker(FILENAME)
        if os.path.isfile(FILENAME) and num_lines == 10:
            print(bcolors.OKGREEN + FILENAME + " has been created and has %d lines" % num_lines + bcolors.ENDC)
        else:
            print(bcolors.FAIL +  FILENAME + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)


def linetotalchecker(FILENAME,TOTALNUMBER):
    try:
        with open(FILENAME) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if TOTALNUMBER in x:
                    print(bcolors.OKGREEN +"Counted line is correct" + bcolors.ENDC  )
                
    except FileNotFoundError:
        print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)
        sys.exit(1)
    time.sleep(0.5)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 




import os 
import sys

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

import sys
sys.path.append('../')
from Classes.shared_scripts.modules import *
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def taskchecker():
    FILETOWORK="/tmp/configurations"
    folderchecker("/tmp/configurations")
    sizechecker("/tmp/configurations")
    try:
        configurations_content = os.listdir(FILETOWORK)
        searchstring = "resolv.conf"
        for x in (x for x in configurations_content if x in searchstring):
            print(bcolors.OKGREEN + FILETOWORK + " " + "has a proper content" + bcolors.ENDC  )
    except FileNotFoundError:
        print(bcolors.FAIL + FILETOWORK + " " + "does not have a proper content" + bcolors.ENDC  )
        sys.exit(1)
            
taskchecker()


import os 
import sys 
import time 
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 


def filestructure():
    FILETOWORK="/tmp/service_users"
    try:
        # Checks if /tmp/service_users is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )

        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if "nologin"  in x:
                    print(bcolors.OKGREEN +  FILETOWORK + " has the necessary content"+ bcolors.ENDC)
                else:
                    print(bcolors.FAIL +  FILETOWORK + " does not have the necessary content"+ bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
    time.sleep(0.5)

    
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #     
    FILETOWORK="/tmp/no_comment_config"
    try:
        # Checks if /tmp/no_comment_config is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )

        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if "#" not in x:
                    print(bcolors.OKGREEN +  FILETOWORK + " has the necessary content"+ bcolors.ENDC)
                else:
                    print(bcolors.FAIL +  FILETOWORK + " does not have the necessary content"+ bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
    time.sleep(0.5)


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #     
    FILETOWORK="/tmp/tcp_services"
    try:
        # Checks if /tmp/tcp_services is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )

        num_lines = sum(1 for line in open(FILETOWORK))
        if num_lines == 25:
            print(bcolors.OKGREEN + FILETOWORK + " " + "has the necessary content" + bcolors.ENDC  )
        else:
            print(bcolors.FAIL +  FILETOWORK + " does not have the necessary content, it has %s lines" % num_lines + bcolors.ENDC)
        sys.exit(1)

    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
        sys.exit(1)
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 


import sys
sys.path.append('../')
from Classes.shared_scripts.modules import *


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def taskchecker():
    filechecker("/mnt/secure")
    sizechecker("/mnt/secure")  
    filechecker("/etc/yum.repos.d/Media.repo.gz")



import os 
import time 
import sys
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

sys.path.append('../')
from Classes.shared_scripts.modules import *

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filestructure():
    try:
        FILETOWORK="/tmp/ordered.txt"
        COUNTED_SERVICES = "12391"
        # Checks if "/tmp/ordered.txt" is created
        sizechecker(FILETOWORK)

        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                pass 
            last_line = x
            clean_last_line = x.strip()
            if clean_last_line[0].isdigit():
                print(bcolors.OKGREEN + FILETOWORK + " " + "is numerated properly" + bcolors.ENDC  )
            else:
                print(bcolors.FAIL + FILETOWORK + " " + "is not numerated properly" + bcolors.ENDC  )
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    time.sleep(0.5)
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 


    try:
        FILETOWORK="/tmp/head.txt"
        num_lines = sum(1 for line in open(FILETOWORK))
        # Checks if "/tmp/head.txt" is created
        if os.path.getsize(FILETOWORK) <= 0 and num_lines == 50:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
            time.sleep(0.5)

        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                pass 
            last_line = x
            clean_last_line = x.strip()
            if clean_last_line[0].isdigit():
                print(bcolors.OKGREEN + FILETOWORK + " " + "is numerated properly" + bcolors.ENDC  )
            else:
                print(bcolors.FAIL + FILETOWORK + " " + "is not numerated properly" + bcolors.ENDC  )
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)

    time.sleep(0.5)
    try:
        FILETOWORK="/tmp/tail.txt"
        num_lines = sum(1 for line in open(FILETOWORK))
        # Checks if "/tmp/tail.txt" is created
        if os.path.getsize(FILETOWORK) <= 0 and num_lines == 50:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )

        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                pass 
            last_line = x
            clean_last_line = x.strip()
            if clean_last_line[0].isdigit():
                print(bcolors.OKGREEN + FILETOWORK + " " + "is numerated properly" + bcolors.ENDC  )
            else:
                print(bcolors.FAIL + FILETOWORK + " " + "is not numerated properly" + bcolors.ENDC  )
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    time.sleep(0.5)

   
    try:
        FILETOWORK="/tmp/lines.txt"
        num_lines = sum(1 for line in open(FILETOWORK))
        # Checks if "/tmp/lines.txt" is created
        if os.path.getsize(FILETOWORK) <= 0 and num_lines == 250:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )

        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                pass 
            last_line = x
            clean_last_line = x.strip()
            if clean_last_line[0].isdigit():
                print(bcolors.OKGREEN + FILETOWORK + " " + "is numerated properly" + bcolors.ENDC  )
            else:
                print(bcolors.FAIL + FILETOWORK + " " + "is not numerated properly" + bcolors.ENDC  )
                sys.exit(1)

    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
        sys.exit(1)
    time.sleep(0.5)
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 



import sys
sys.path.append('../')
from Classes.shared_scripts.modules import *

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def taskchecker():
    filechecker("/tmp/fruits")
    sizechecker("/tmp/services")
    linechecker("/tmp/top10")
    linechecker("/tmp/bottom10")
    sizechecker("/tmp/sorted_fruits")
    filechecker("/tmp/sorted_fruits")

    sizechecker("/tmp/counted_services")
    filechecker("/tmp/counted_services")
    linetotalchecker("/tmp/counted_services", '1300')
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 
